@@ -1,9 +1,9 @@
 /*
- * $Id: dialog.c,v 1.285 2021/06/22 00:11:37 tom Exp $
+ * $Id: dialog.c,v 1.289 2022/07/28 21:11:36 tom Exp $
  *
  *  cdialog - Display simple dialog boxes from shell scripts
  *
- *  Copyright 2000-2020,2021	Thomas E. Dickey
+ *  Copyright 2000-2021,2022	Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -24,20 +24,6 @@
  *	Savio Lam (lam836@cs.cuhk.hk)
  */
 
-#include <dialog.h>
-
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-
-#ifdef HAVE_SETLOCALE
-#include <locale.h>
-#endif
-
-#ifdef STDC_HEADERS
-#include <stddef.h>		/* for offsetof, usually via stdlib.h */
-#endif
-
 #include <dlg_internals.h>
 
 #define USEMAX_ARGS	20
@@ -907,9 +893,6 @@ call_inputmenu(CALLARGS)
 
     dialog_vars.input_menu = TRUE;
 
-    if (dialog_vars.max_input == 0)
-	dialog_vars.max_input = MAX_LEN / 2;
-
     if (dialog_vars.extra_label == 0) {
 	free_extra_label = TRUE;
 	dialog_vars.extra_label = dlg_strclone(_("Rename"));
@@ -1555,7 +1538,7 @@ Help(void)
     static const char *const tbl_1[] =
     {
 	"cdialog (ComeOn Dialog!) version %s",
-	"Copyright 2000-2020,2021 Thomas E. Dickey",
+	"Copyright 2000-2021,2022 Thomas E. Dickey",
 	"This is free software; see the source for copying conditions.  There is NO",
 	"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.",
 	"",
@@ -1988,6 +1971,10 @@ main(int argc, char *argv[])
 		    argv[1]);
 	    Usage(temp);
 	}
+#ifdef HAVE_COLOR
+	dialog_state.use_colors = USE_COLORS;	/* use colors by default? */
+	dialog_state.use_shadow = USE_SHADOW;	/* shadow dialog boxes by default? */
+#endif
 	if (dlg_parse_rc() == -1) {	/* Read the configuration file */
 	    handle_leaks();
 	    dlg_exiterr("dialog: dlg_parse_rc");
@@ -1995,7 +1982,7 @@ main(int argc, char *argv[])
 	dlg_create_rc(argv[2]);
 	dlg_exit(DLG_EXIT_OK);
     }
-#endif
+#endif /* HAVE_RC_FILE */
     else {
 	/*
 	 * Handle combinations of common options including --print-text-only
